boss_on_reference_plane

Function boss_on_reference_plane 

pub fn boss_on_reference_plane() -> Program
A box with a round boss standing on it, sketched on a reference plane: the plane half a unit above the box’s top (lifted, offset from extrude(box,end)), a circle sketched on it, and extruded back down through the gap and into the box, joined to it (boss) — the part is extrude(boss).